#        Name : perp_line_plane
# Description : draws a line perpendicular to the selected face, starting from a point
#      Author : Didier Bur
#       Usage : select a construction point and a face, enter line length and here you are.
#        Date : 12.Oct.2oo4
#        Type : tool

require 'sketchup.rb'

def perp_line_plane

model = Sketchup.active_model
model.start_operation "Line perpendicular to a face"
entities = model.active_entities
ss = model.selection


# Selection error checking
if ss.empty? 
  UI.messagebox("No selection.")
  return nil
end

# Who's the face and who's the face ?
ent1 = ss[0]
ent2 = ss[1]
if( ent1.typename == "ConstructionPoint")
  pt = ent1
  fc = ent2
  else
  fc = ent1
  pt = ent2
end
if fc.typename != "Face" or pt.typename != "ConstructionPoint"
  UI.messagebox("Selected objects are not of the correct type.")
  return nil
end

prompts = ["Length of line"]
values = [100.cm]
results = inputbox prompts, values, "Line Dimension"
return if not results
line_len = results[0].to_l

plan = fc.plane
norm = fc.normal
vec = fc.normal
norm.length = line_len
pt1 = pt.position
pt2 = Geom::Point3d.new(pt1.x + norm[0], pt1.y + norm[1], pt1.z + norm[2])
Sketchup.active_model.active_entities.add_line( pt1, pt2 )
end #of def

if( not file_loaded?("perp_line_plane.rb") )
    add_separator_to_menu("Plugins")
    UI.menu("Plugins").add_item("Line perpendicular to face") { perp_line_plane }
end
file_loaded("perp_line_plane.rb")